==> fabricdocker-0.1.2.tar.gz: fabricdocker-0.1.2/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'fabric==2.6.0',
    'invoke==1.5.0'
]

setup_requirements = []

test_requirements = []

setup(
    author="Guillermo del Fresno",
    author_email='gdelfresno@gmail.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    description="Modern Fabric tools for docker",
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='fabricdocker',
    name='fabricdocker',
    packages=find_packages(include=['fabricdocker', 'fabricdocker.compose']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/gdelfresno/fabricdocker',
    version='0.1.2',
    zip_safe=False,
)

==> fabricdocker-0.1.3.tar.gz: fabricdocker-0.1.3/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'fabric==2.6.0',
    'invoke==1.5.0'
]

setup_requirements = []

test_requirements = []

setup(
    author="Guillermo del Fresno",
    author_email='gdelfresno@gmail.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    description="Modern Fabric tools for docker",
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='fabricdocker',
    name='fabricdocker',
    packages=find_packages(include=[
        'fabricdocker', 'fabricdocker.compose', 'fabricdocker.docker'
    ]),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/gdelfresno/fabricdocker',
    version='0.1.3',
    zip_safe=False,
)
